@@ -18,8 +18,9 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 import os
+from pathlib import Path
 
-from gi.repository import Gio, GLib, Xdp
+from gi.repository import GLib, Gio, Xdp
 
 
 def get_user_config_dir() -> str:
@@ -28,7 +29,7 @@ def get_user_config_dir() -> str:
         return GLib.get_user_config_dir()
 
     return os.environ.get(
-        "HOST_XDG_CONFIG_HOME", os.path.join(GLib.get_home_dir(), "." + "config")
+        "HOST_XDG_CONFIG_HOME", str(Path(GLib.get_home_dir(), "." + "config"))
     )
 
 
@@ -39,7 +40,7 @@ def get_user_data_dir() -> str:
 
     return os.environ.get(
         "HOST_XDG_DATA_HOME",
-        os.path.join(GLib.get_home_dir(), "." + "local", "share"),
+        str(Path(GLib.get_home_dir(), "." + "local", "share")),
     )
 
 
@@ -48,7 +49,7 @@ def get_system_data_dirs() -> list[str]:
     data_dirs = GLib.get_system_data_dirs()
 
     if Xdp.Portal.running_under_flatpak():
-        data_dirs.remove(os.path.join(os.sep, "app", "share"))
+        data_dirs.remove(str(Path(os.sep, "app", "share")))
 
     return data_dirs
 
@@ -63,9 +64,11 @@ def get_debug_info() -> str:
         "HOST_XDG_DATA_HOME",
     )
 
+    home = Path(GLib.get_home_dir()).name
     output = ""
     for environment_variable in environment_variables:
-        output += f"{environment_variable}: “{GLib.getenv(environment_variable)}”\n"
+        original = f"{environment_variable}: “{GLib.getenv(environment_variable)}”\n"
+        output += original.replace(home, "[REDACTED]")
 
     return str(output)
 
@@ -75,12 +78,9 @@ def create_schema_sources_list() -> list[Gio.SettingsSchemaSource]:
     sources = []
 
     for data_dir in GLib.get_system_data_dirs():
-        try:
-            source = Gio.SettingsSchemaSource.new_from_directory(
-                os.path.join(data_dir, "glib-2.0", "schemas"), None, True
-            )
+        path = Path(data_dir, "glib-2.0", "schemas")
+        if path.is_dir():
+            source = Gio.SettingsSchemaSource.new_from_directory(str(path), None, True)
             sources.append(source)
-        except GLib.Error:
-            pass
 
     return sources
