@@ -17,21 +17,20 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-
-from typing import TypedDict
 from enum import IntEnum, auto
+from typing import TypedDict
 
 from gi.repository import Gio
 
 
-class RefineSettingsSource(TypedDict):
+class SettingsSource(TypedDict):
     """Dictionary for storing important `Gio.Settings`-related data."""
 
     settings: Gio.Settings | None
     schema: Gio.SettingsSchema | None
 
 
-class RefineLogicalDirectionType(IntEnum):
+class LogicalDirectionType(IntEnum):
     """Logical direction types."""
 
     START = auto()
