@@ -17,11 +17,11 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
 from typing import Any, cast
 
-from gi.repository import Adw, Gio, GObject, Gtk
+from gi.repository import Adw, GObject, Gio, Gtk
 
+from refine.logger import logger
 from refine.widgets.base import BaseInterface
 
 
@@ -34,16 +34,16 @@ class ActionRow(Adw.ActionRow, BaseInterface):
 
     __gtype_name__ = "ActionRow"
 
-    schema = cast(Gio.SettingsSchema, GObject.Property(type=Gio.SettingsSchema))
-    schema_id = cast(str, GObject.Property(type=str))
-    key = cast(str, GObject.Property(type=str))
-    is_valid_setting = cast(bool, GObject.Property(type=bool, default=False))
+    schema = cast("Gio.SettingsSchema", GObject.Property(type=Gio.SettingsSchema))
+    schema_id = cast("str", GObject.Property(type=str))
+    key = cast("str", GObject.Property(type=str))
+    is_valid_setting = cast("bool", GObject.Property(type=bool, default=False))
 
     restart_required = GObject.Property(type=bool, default=False)
 
     def value_set(self, value: Any) -> None:
         """Log key-value pair."""
-        logging.debug(f"Set key “{self.key}” to “{value}”")
+        logger.debug(f"Set key “{self.key}” to “{value}”")
 
         if not self.restart_required:
             return
