@@ -35,6 +35,7 @@ class DataComboRow(ComboRow):
     revert_button = Gtk.Template.Child()
     revealer = Gtk.Template.Child()
 
+    require_file = GObject.Property(type=str, default="")
     lookup_directory = GObject.Property(type=str, default="")
     data_subdirectory = GObject.Property(type=str, default="")
 
@@ -55,12 +56,17 @@ class DataComboRow(ComboRow):
             settings.get_user_data_dir(), self.data_subdirectory
         ).glob("*")
 
-        if bool(self.lookup_directory):
-            data_dirs_list = [
-                path
-                for path in data_dirs_list
-                if Path(path, self.lookup_directory).is_dir()
-            ]
+        data_dirs_list = [
+            path
+            for path in data_dirs_list
+            if Path(path, self.lookup_directory).is_dir()
+        ]
+
+        data_dirs_list = [
+            path
+            for path in data_dirs_list
+            if Path(path, self.lookup_directory, self.require_file).exists()
+        ]
 
         data_dirs_list = [path.name for path in data_dirs_list if path.is_dir()]
 
